<?php

namespace Drupal\Tests\search_api_lunr\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\node\Entity\Node;
use Drupal\Tests\search_api_lunr\Kernel\LunrTestingTrait;

/**
 * @group search_api_lunr
 */
class LunrSearchTest extends WebDriverTestBase {

  use LunrTestingTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The modules array.
   *
   * @var array
   */
  public static $modules = [
    'node',
    'block',
    'user',
    'system',
    'search_api',
    'search_api_lunr',
  ];

  /**
   * @var \Drupal\search_api\IndexInterface
   */
  protected $index;

  /**
   * @var \Drupal\search_api_lunr\Plugin\search_api\backend\LunrBackend
   */
  protected $backend;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->index = $this->createServerIndex();
    $this->backend = $this->index->getServerInstance()->getBackend();
  }

  /**
   * Test the lunr search.
   */
  public function testLunrSearch() {
    $this->drupalPlaceBlock('search_api_lunr_form', [
      'index' => $this->index->id(),
      'autocomplete_index' => $this->index->id(),
    ]);

    Node::create([
      'title' => 'Foo',
      'type' => 'page',
      'uid' => 1,
    ])->save();
    Node::create([
      'title' => 'Bar',
      'type' => 'page',
      'uid' => 1,
    ])->save();
    $this->index->indexItems();

    $this->drupalGet('<front>');

    // Assert the UI autocomplete finds the result with a partial search.
    $this->getSession()->getPage()->fillField('q', 'Fo');
    $this->getSession()->getDriver()->keyDown($this->cssSelectToXpath('.ui-autocomplete-input'), 'o');
    $this->getSession()->wait(1000, 'false');
    $this->assertSession()->elementContains('css', '.ui-autocomplete', 'Foo');

    // Submitting the form will bring up full search results.
    $this->submitForm([
      'q' => 'Foo',
    ], 'Search');
    $this->getSession()->wait(1000, 'false');
    $this->assertSession()->linkExists('Foo');

    // Search is fuzzy based.
    $this->submitForm([
      'q' => 'baz',
    ], 'Search', 'search-page-form');
    $this->getSession()->wait(1000, 'false');
    $this->assertSession()->linkExists('Bar');

    // Searching for a term that doesn't exist will show a no results message.
    $this->submitForm([
      'q' => 'invalid',
    ], 'Search', 'search-page-form');
    $this->getSession()->wait(1000, 'false');
    $this->assertSession()->pageTextContains('No results found.');
  }

}
